==> pakfire-0.9.22.tar.gz: pakfire-0.9.22/python/pakfire/repository/system.py <==
#!/usr/bin/python
###############################################################################
#                                                                             #
# Pakfire - The IPFire package management system                              #
# Copyright (C) 2011 Pakfire development team                                 #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################

import base
import database

class RepositorySystem(base.RepositoryFactory):
	def __init__(self, pakfire):
		base.RepositoryFactory.__init__(self, pakfire, "@system", "Local repository")

		# Open database connection.
		self.db = database.DatabaseLocal(self.pakfire, self)

		# Tell the solver, that these are the installed packages.
		self.pool.set_installed(self.solver_repo)

	@property
	def priority(self):
		"""
			The local repository has always a high priority.
		"""
		return 10

	def update(self, force=False, offline=False):
		if not force:
			force = len(self) == 0

		if force:
			self.index.clear()
			for pkg in self.db.packages:
				self.index.add_package(pkg)

	def commit(self):
		# Commit the database to disk.
		self.db.commit()

	def add_package(self, pkg):
		# Add package to the database.
		self.db.add_package(pkg)
		self.index.add_package(pkg)

	def rem_package(self, pkg):
		# Remove package from the database.
		self.index.rem_package(pkg)

	@property
	def filelist(self):
		# XXX ugly?

		for pkg in self.db.packages:
			for file in pkg.filelist:
				yield file

==> pakfire-0.9.23.tar.gz: pakfire-0.9.23/python/pakfire/repository/system.py <==
#!/usr/bin/python
###############################################################################
#                                                                             #
# Pakfire - The IPFire package management system                              #
# Copyright (C) 2011 Pakfire development team                                 #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################

import os

import base
import database

import pakfire.packages as packages
import pakfire.util as util

from pakfire.constants import *
from pakfire.i18n import _

class RepositorySystem(base.RepositoryFactory):
	def __init__(self, pakfire):
		base.RepositoryFactory.__init__(self, pakfire, "@system", "Local repository")

		# Open database connection.
		self.db = database.DatabaseLocal(self.pakfire, self)

		# Tell the solver, that these are the installed packages.
		self.pool.set_installed(self.solver_repo)

	@property
	def cache_file(self):
		return os.path.join(self.pakfire.path, PACKAGES_SOLV)

	@property
	def priority(self):
		"""
			The local repository has always a high priority.
		"""
		return 10

	def update(self, force=False, offline=False):
		# XXX using the cache is currently disabled
		#if not force:
		#	if os.path.exists(self.cache_file):
		#		self.index.read(self.cache_file)
		#
		#	force = len(self) == 0

		force = True

		if force:
			# Create a progressbar.
			pb = util.make_progress(_("Loading installed packages"), len(self.db))

			# Remove all data from the current index.
			self.index.clear()

			i = 0
			for pkg in self.db.packages:
				if pb:
					i += 1
					pb.update(i)

				self.index.add_package(pkg)

			self.index.optimize()

			if pb:
				pb.finish()

	def commit(self):
		# Commit the database to disk.
		self.db.commit()

		# Make sure that all data in the index is accessable.
		self.index.optimize()

		# Write the content of the index to a file
		# for fast parsing.
		# XXX this is currently disabled
		#self.index.write(self.cache_file)

	def add_package(self, pkg):
		# Add package to the database.
		self.db.add_package(pkg)
		self.index.add_package(pkg)

	def rem_package(self, pkg):
		assert isinstance(pkg, packages.SolvPackage), pkg

		# Remove package from the database.
		self.db.rem_package(pkg)
		self.index.rem_package(pkg)

	@property
	def filelist(self):
		return self.db.get_filelist()
